@@ -28,5 +28,5 @@ cmake ${CMAKE_ARGS} .. \
 cmake --build . --config Release -- -j$CPU_COUNT
 cmake --build . --config Release --target install
 if [[ "${CONDA_BUILD_CROSS_COMPILATION}" != "1" ]]; then
-ctest  --output-on-failure -C Release -E "INTEGRATION|PERFORMANCE|REGRESSION"
+ctest  --output-on-failure -C Release -E "INTEGRATION|PERFORMANCE|REGRESSION|UNIT_ign"
 fi
